Documentation
¶
Index ¶
- Variables
- func Banner(title string)
- func Fail(name, detail string)
- func Info(msg string)
- func Logf(format string, args ...any)
- func Section(title string)
- func Skip(name, detail string)
- func Success(name, detail string)
- func Summary(pass, warn, fail, skipped int)
- func Warn(name, detail string)
- func WithSpinner(msg string, fn func() error) error
- type Spinner
Constants ¶
This section is empty.
Variables ¶
var ( Bold = lipgloss.NewStyle().Bold(true) Faint = lipgloss.NewStyle().Faint(true) Green = lipgloss.NewStyle().Foreground(lipgloss.Color("2")) Red = lipgloss.NewStyle().Foreground(lipgloss.Color("1")) Yellow = lipgloss.NewStyle().Foreground(lipgloss.Color("3")) Orange = lipgloss.NewStyle().Foreground(lipgloss.Color("208")) Cyan = lipgloss.NewStyle().Foreground(lipgloss.Color("6")) IconPass = Green.Render("✅") IconFail = Red.Render("❌") IconWarn = Yellow.Render("⚠️") IconSkip = Faint.Render("⏭") IconInfo = Cyan.Render("ℹ") )
Functions ¶
func WithSpinner ¶
WithSpinner runs fn while showing an animated spinner with msg. The spinner is stopped before fn returns so that fn's own stdout output (if any) is not garbled.
Types ¶
type Spinner ¶
type Spinner struct {
// contains filtered or unexported fields
}
Spinner provides an animated terminal spinner that works alongside normal stdout output. It is safe for non-TTY environments (becomes a no-op).
func NewSpinner ¶
func NewSpinner() *Spinner
Click to show internal directories.
Click to hide internal directories.